icsemantic.catalog.indexes.translation

Package platecom :: Package ontocatalog :: Package indexes :: Module translation |
[hide private]
[frames] | no frames]

# Module translation

source code

TranslationIndex is an index for the catalog that does not index anything.

Instead, the _apply_index performs a query to a thesaurus object for translations of the keyword parameters and then queries the site catalog for the result of the thesaurus query.

Classes | [hide private]
| TranslationIndex An index for translations that does not index anything

Functions | [hide private]
manage_addTranslationIndex(self, id, extra=None, REQUEST=None, RESPONSE=None, URL3=None) Add a fake index | source code

Variables | [hide private]
| manage_addTranslationIndexForm = `DTMLFile('dtml/addFakeIndex',`...``

Variables Details | [hide private]

  ### manage_addTranslationIndexForm Value:
      DTMLFile('dtml/addFakeIndex', globals())